@@ -24,5 +24,9 @@ utils::globalVariables(
     "data_mutate_obj",
     "gini_meas",
     "total_gini_meas",
-    "quantiles")
+    "quantiles",
+    "mean_max_variation",
+    "newds",
+    "freqx",
+    "..density..")
 )
