@@ -13,12 +13,12 @@
 # For adjusting or adding more apps it may be useful to follow:
 # https://deanattali.com/2015/04/21/r-package-shiny-app/
 run_app <- function() {
-  if (!requireNamespace("shinythemes", quietly = TRUE)) {
-    stop("package \"shinytheme\" is required to run this app")
-  }
-  if (!requireNamespace("shinyalert", quietly = TRUE)) {
-    stop("package \"shinyalert\" is required to run this app")
-  }
+  # if (!requireNamespace("shinythemes", quietly = TRUE)) {
+  #   stop("package \"shinytheme\" is required to run this app")
+  # }
+  # if (!requireNamespace("shinyalert", quietly = TRUE)) {
+  #   stop("package \"shinyalert\" is required to run this app")
+  # }
   appDir <- system.file("shiny-examples",
                         "gravitas_app",
                         package = "gravitas"
